@@ -2,17 +2,15 @@ package GitStore;
 BEGIN {
   $GitStore::AUTHORITY = 'cpan:YANICK';
 }
-{
-  $GitStore::VERSION = '0.15';
-}
 #ABSTRACT: Git as versioned data store in Perl
-
+$GitStore::VERSION = '0.16';
 use Moose;
 use Moose::Util::TypeConstraints;
 use Git::PurePerl;
 use Carp;
 
 use Path::Class qw/ dir file /;
+use Path::Tiny;
 
 use List::Util qw/ first /;
 
@@ -153,6 +151,15 @@ sub branch_head {
     return $self->git->ref_sha1('refs/heads/' . $branch);
 }
 
+sub create {
+    my( $class, $dir ) = @_;
+
+    path($dir)->mkpath;
+    Git::PurePerl->init( directory => $dir );
+
+    return $class->new($dir);
+}
+
 # Load the current head version from repository. 
 sub load {
     my $self = shift;
@@ -230,6 +237,17 @@ sub get {
     return $self->deserializer->($self,$path,$object->content);
 }
 
+sub exist {
+    my ( $self, $path ) = @_;
+
+    $path = file( $self->_normalize_path($path) );
+
+    my $dir = $self->_cd_dir($path) or return;
+
+    return $dir->{FILES}{$path->basename};
+}
+
+
 sub set {
     my ( $self, $path, $content ) = @_;
     
@@ -441,13 +459,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 GitStore - Git as versioned data store in Perl
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -469,6 +489,15 @@ version 0.15
 
 It is inspired by the Python and Ruby binding. check SEE ALSO
 
+=head1 CLASS FUNCTIONS
+
+=head2 create( $directory )
+
+Creates the directory, initialize it as a git repository,
+and returns its associated C<GitStore> object.
+
+    my $gs = GitStore->create( '/tmp/mystore' );
+
 =head1 METHODS
 
 =head2 new
@@ -602,6 +631,10 @@ commit the B<set> changes into Git
 
 discard the B<set> changes
 
+=head2 exist($path)
+
+Returns I<true> if an object exists at the given path.
+
 =head2 history($path)
 
 Returns a list of L<GitStore::Revision> objects representing the changes
@@ -683,7 +716,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Fayland Lam <fayland@gmail.com>.
+This software is copyright (c) 2015 by Fayland Lam <fayland@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
